@@ -15,9 +15,25 @@
  *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
+
+#if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6) || defined(__clang__)
+# define HAVE_PRAGMA_DIAGNOSTIC 1
+#endif
+
+#if defined HAVE_PRAGMA_DIAGNOSTIC && defined __clang__
+# pragma clang diagnostic push
+# pragma clang diagnostic ignored "-Wreserved-macro-identifier"
+#endif
+
 #include "config.h"
 
+#if defined HAVE_PRAGMA_DIAGNOSTIC && defined __clang__
+# pragma clang diagnostic pop
+#endif
+
+
 #ifndef HAVE_ICONV_H
+
 #include "codepage.h"
 
 Codepage_t codepages[]= {
@@ -114,6 +130,6 @@ Codepage_t codepages[]= {
 	{ 0 }
 };
 #else
-/* Should down  ISO C forbids an empty translation unit warning [-Wpedantic]: */
+/* Shut up warning: ISO C forbids an empty translation unit warning [-Wpedantic]: */
 typedef int make_iso_compilers_happy;
 #endif
